@@ -1,5 +1,4 @@
 /*
- * $Xorg: XMultibuf.c,v 1.6 2001/02/09 02:03:49 xorgcvs Exp $
  *
 Copyright 1989, 1998  The Open Group
 
@@ -25,10 +24,7 @@ in this Software without prior written authorization from The Open Group.
  *
  * Authors:  Jim Fulton, MIT X Consortium
  */
-/* $XFree86: xc/lib/Xext/XMultibuf.c,v 1.5 2001/12/14 19:55:00 dawes Exp $ */
 
-#define NEED_EVENTS
-#define NEED_REPLIES
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -36,7 +32,8 @@ in this Software without prior written authorization from The Open Group.
 #include <stdio.h>
 #include <X11/extensions/Xext.h>
 #include <X11/extensions/extutil.h>
-#include <X11/extensions/multibufst.h>
+#include <X11/extensions/multibufproto.h>
+#include <X11/extensions/multibuf.h>
 
 static XExtensionInfo _multibuf_info_data;
 static XExtensionInfo *multibuf_info = &_multibuf_info_data;
@@ -634,7 +631,7 @@ Window XmbufCreateStereoWindow (
     req->borderWidth = border_width;
     req->depth = depth;
     req->class = class;
-    if (visual == CopyFromParent)
+    if (visual == (Visual *)CopyFromParent)
 	req->visual = CopyFromParent;
     else
 	req->visual = visual->visualid;
